<p><i>Note: Before using the keyboard you must set the focus within the frame by clicking once on the frame.</i></p>

<table>
  <thead>
    <tr><th>Key</th><th>Action</th></tr>
  </thead>
  <tbody>
    <tr>
      <td>t<br />Shift + t</td>
      <td>Translate the sentence or paragraph of the current word</td>
    </tr>
    <tr>
      <td>c<br />Shift + c</td>
      <td>Copy the sentence or whole paragraph of the current word to clipboard</td>
    </tr>
    <tr>
      <td>Right</td>
      <td>Move to next word</td>
    </tr>
    <tr>
      <td>Shift + Right</td>
      <td>Move to next unknown or learning word (skip known and ignored)</td>
    </tr>
    <tr>
      <td>Left</td>
      <td>Move to previous word</td>
    </tr>
    <tr>
      <td>Shift + Left</td>
      <td>Move to previous unknown or learning word (skip known and ignored)</td>
    </tr>
    <tr>
      <td>1-5</td>
      <td>Set status(es) to 1 (Learning) to 5 (Learned)</td>
    </tr>
    <tr>
      <td>i</td>
      <td>Mark term(s) as "Ignored"</td>
    </tr>
    <tr>
      <td>w</td>
      <td>Mark term(s) as "Well Known"</td>
    </tr>
  </tbody>
</table>
  
<p>You can also "bulk update" statuses by holding down Shift and clicking with the mouse.  All of the underlined terms will then be affected when you hit 1,2,...,W.</p>
