{% extends 'base.html' %}

{% block header %}
{% if term.language_id is none %}New Term{% else %}Edit Term{% endif %}
{% endblock %}

{% block body %}
<div id="term_form_left">
  {% include('term/_form.html') %}
  <a href="/term/index">back to list</a>

  {% if term.id %}
  <form
    method="post"
    action="/term/delete/{{ term.id }}"
    onsubmit="return confirm('Are you sure you want to delete this item?');">
    <button class="btn">Delete</button>
  </form>
  {% endif %}
</div>


<div id="term_form_right">
  <iframe name="dictframe" class="rightreadingframe" src="/read/empty" scrolling="auto"
          style="height: 100%; width: 100%;" frameBorder="1">
    Frame support required.
  </iframe>
</div>

{% endblock %}
